@@ -20,12 +20,7 @@ class PollOption(PRAWBase):
         # By ID -- print the option with ID "576797"
         print(poll_data.option("576797"))
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     ============== =================================================
     Attribute      Description
@@ -37,11 +32,11 @@ class PollOption(PRAWBase):
 
     """
 
-    def __repr__(self):
-        """Make a string representation of the PollData."""
+    def __repr__(self) -> str:
+        """Return an object initialization representation of the instance."""
         return f"PollOption(id={self.id!r})"
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return a string version of the PollData, its text."""
         return self.text
 
@@ -60,12 +55,7 @@ class PollData(PRAWBase):
             print(f"{option} ({option.vote_count} votes)")
         print(f"I voted for {poll_data.user_selection}.")
 
-    **Typical Attributes**
-
-    This table describes attributes that typically belong to objects of this class.
-    Since attributes are dynamically provided (see
-    :ref:`determine-available-attributes-of-an-object`), there is not a guarantee that
-    these attributes will always be present, nor is this list necessarily complete.
+    .. include:: ../../typical_attributes.rst
 
     ======================== =========================================================
     Attribute                Description
